---
title: minio
type: docs
---

[![Source Code](https://img.shields.io/badge/gitea-source%20code-blue?logo=gitea&logoColor=white)](https://gitea.rknet.org/ansible/xoxys.minio) [![Build Status](https://img.shields.io/drone/build/ansible/xoxys.minio?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/ansible/xoxys.minio) [![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg?label=license)](https://gitea.rknet.org/ansible/xoxys.minio/src/branch/main/LICENSE)

Setup Minio S3 server

<!--more-->

- [Default Variables](#default-variables)
  - [minio_access_key](#minio_access_key)
  - [minio_base_dir](#minio_base_dir)
  - [minio_bind_ip](#minio_bind_ip)
  - [minio_bind_port](#minio_bind_port)
  - [minio_client_version](#minio_client_version)
  - [minio_console_bind_ip](#minio_console_bind_ip)
  - [minio_console_bind_port](#minio_console_bind_port)
  - [minio_cronjobs](#minio_cronjobs)
  - [minio_data_dirs](#minio_data_dirs)
  - [minio_extra_groups](#minio_extra_groups)
  - [minio_group](#minio_group)
  - [minio_kms_secret_key](#minio_kms_secret_key)
  - [minio_packages](#minio_packages)
  - [minio_secret_key](#minio_secret_key)
  - [minio_server_env_extra](#minio_server_env_extra)
  - [minio_server_opts](#minio_server_opts)
  - [minio_server_version](#minio_server_version)
  - [minio_user](#minio_user)
  - [minio_user_home](#minio_user_home)
- [Dependencies](#dependencies)

---

## Default Variables

### minio_access_key

Minio access key (should be changed for prod environments)

#### Default value

```YAML
minio_access_key: demo
```

### minio_base_dir

#### Default value

```YAML
minio_base_dir: /opt/minio
```

### minio_bind_ip

#### Default value

```YAML
minio_bind_ip: 127.0.0.1
```

### minio_bind_port

#### Default value

```YAML
minio_bind_port: 61000
```

### minio_client_version

#### Default value

```YAML
minio_client_version: latest
```

### minio_console_bind_ip

#### Default value

```YAML
minio_console_bind_ip: 127.0.0.1
```

### minio_console_bind_port

#### Default value

```YAML
minio_console_bind_port: 61001
```

### minio_cronjobs

#### Default value

```YAML
minio_cronjobs: []
```

#### Example usage

```YAML
minio_cronjobs:
  - name: maintenance
    minute: "0"
    hour: "0"
    day: "*"
    month: "*"
    weekday: "*"
    job: "mc rm --older-than 30d --recursive --force my_bucket/logs"
    user: "{{ minio_user }}"
    cron_file: "minio"
    state: "present"
```

### minio_data_dirs

#### Default value

```YAML
minio_data_dirs:
  - '{{ minio_base_dir }}/data'
```

### minio_extra_groups

#### Default value

```YAML
minio_extra_groups: []
```

### minio_group

#### Default value

```YAML
minio_group: '{{ minio_user }}'
```

### minio_kms_secret_key

The key to use for encrypting the MinIO backend (users, groups, policies, and server configuration). Use the following format when specifying the encryption key: `<key-name>:<encryption-key>` Replace the `<key-name>` with any string. You must use this key name if you later migrate to using a dedicated KMS for managing encryption keys. Replace `<encryption-key>` with a 32-bit base64 encoded value.

### minio_packages

Packages to install as requirements for the Minio server.

#### Default value

```YAML
minio_packages: []
```

### minio_secret_key

Minio secret key (should be changed for prod environments)

#### Default value

```YAML
minio_secret_key: passphrase
```

### minio_server_env_extra

Additional environment variables to be set in minio server environment.

#### Default value

```YAML
minio_server_env_extra: []
```

### minio_server_opts

Additional Minio server CLI options.

#### Default value

```YAML
minio_server_opts: []
```

### minio_server_version

Minio release to install.

#### Default value

```YAML
minio_server_version: latest
```

#### Example usage

```YAML
minio_server_version: 2020-05-16T01-33-21Z
```

### minio_user

Runtime user and group for the Minio server service.

#### Default value

```YAML
minio_user: minio
```

### minio_user_home

#### Default value

```YAML
minio_user_home: /home/{{ minio_user }}
```



## Dependencies

None.
